\name{BGandNorm}
\alias{BGandNorm}
\title{Background Correction and Normalization Between Arrays}
\description{
  	For Background correction it uses the 'backgroundCorrect'
 	function of 'limma' package ('half','normexp'). For
	Normalization between arrays it uses 'limma'
	function 'normalizeBetweenArrays' ('quantile','vsn'). 
}
\usage{
	BGandNorm(RGlist, BGmethod, NORMmethod, foreground, 
	background, offset, makePLOTpre, makePLOTpost)
}
\arguments{
  \item{RGlist}{an 'RGList' object }
  \item{BGmethod}{Method for the BG corection. Possible values are: 
	'none','half','normexp'. See ?backgroundCorrect in limma package
	for details }
  \item{NORMmethod}{Method for Norm between arrays. Possible values
	can be: 'none','quantile',vsn'. See ?normalizeBetweenArrays in limma
	package }
  \item{foreground}{Foreground Signal to be used for the analysis. 
	Possible values are 'MeanSignal','ProcessedSignal'
        }
  \item{background}{Background Signal to be used for the BG correction. The
	values can be: 'BGMedianSignal','BGUsed' }
  \item{offset}{numeric value to add to the intensities before log transforming.
	The offset shrunks the log ratios towards zero at the lower intensities.
	 See limma user guide for details }
  \item{makePLOTpre}{density Plots, box plots, MVA plots and RLE plots with the
		raw signal}
  \item{makePLOTpost}{density Plots, box plots, MVA plots and RLE plots with the
                normalized signal }
}
\details{
	In order to make direct comparisons of data coming from different chips it 
	is important to remove sources of variation of non biological 
	nature that may exists between arrays. Systematic non-biological 
	differences between chips become relevant in several obvious ways 
	especially during labeling and hybridization, and bias the relative 
	measures on any two chips when we want to quantify differences due to different
	treatment between two samples.
	Normalization is the attempt to compensate for systematic technical
	differences between chips, to see more clearly the systematic biological 
	differences between samples.
	First data are background corrected. We produce a Background Subtracted 
	Signal.
	The Background Signal Used depends on the AFE settings for the type 
	of background method calculation and the settings for spatial detrend. Usually, 
	the Background Signal Used is the sum of the Local Background Signal + the 
	Spatial Detrending Surface Value computed by the AFE software. 
	For the Background correction we use the 'backgroundCorrect'
  	function of 'limma' package with options <'half','normexp'>	
	This function is designed to produce positive corrected intensities. 
	First, any intensity value lower than 0.5 is reset to be equal to 0.5. 
	Besides, and offset value (normally 50) is used. This offset value adds 
	a constant to the intensity values before log-transforming, so that the log 
	ratios are shrunk towards zero at the lower intensities.
	After background correction, data are normalized between arrays using 
	'limma' function 'normalizeBetweenArrays' with options <'quantile','vsn'>
	
	
	For foreground signal,the user can choose between the 'MeanSignal' and the
	'ProcessedSignal' and between the 'BGMedianSignal' and the 'BGUsed' for 
	background correction.		
	The user may want to have a look at different graphics (density plots, etc ...) 
	in order to decide what signal is more suitable to use. For details about signal processing
	see AFE User Guide. 
	'MeanSignal' is the spot Raw mean signal.
	'ProcessedSignal' is the signal processed by the Agilent Feature Extraction image
	analysis software (AFE). It contains the  Multiplicatively Detrend Bacground
	Substracted Signal if the detrending is selected and it helps. If the detrending
	does not help, the 'ProcessedSignal' will be the Bacground Subtracted Signal. 
	'BGMedianSignal' is the Median local background signal. 
	'BGUsed' depends on the AFE software settings for the type of background method calculation and the
	setting for the spatial detrend. Usually, the Background Signal Used is the sum 
	of the local bacground + the spatial detrending surface value computed by 
	the AFE software. To view the values used to calculate this variable using
	different bakground signals and settings of spatial detrend and global background
	adjust, see Table 33 on page 213 of the AFE User Guide. 
	Limma function 'backgroundCorrect' is used for the BG correction. This function is
	designed to produce positive intensities. Any intensity value lower less than 0.5
	is reset to be equal to 0.5. Additionally, a constant of 50 (normally) is used
	as a offset that it is added to the intensity values before the log transformation. 
	The propouse of this calculation
	is to shrunk the log ratios to zero at the lower intensities and thus to
	reduce the variability of log-ratios for low intensity spots. The optimal choice
	for the offset is the one which makes the variability of the log-ratios as constant as
	possible accross the range of intensity values (Smyth, G. in BioC mailing List).  
	If the 'half' method is chosen for Background Correction, the method will substract
	the chosen BACKGROUND signal to the chosen FOREGROUND signal, to produce positive
	corrected intensities according to the 'half' method. If the 'normexp' method 
	is selected, then a convolution of normal and exponential
     	distributions is fitted to foreground intensities using 
	background intensities as a covariate, and the expected signal
     	given the observed foreground becomes the corrected intensity. See 'limma' user
	guide for details.  
}
\value{
	a 'RGList' object, containing in 'RGList\$G' the log-2 normalized intensities 
}
\references{  
	Bolstad, B. M. (2001), Probe level quantile normalization of
	high density oligonucleotide array data. Unpublished Manuscript:
	\url{http://bmbolstad.com/stuff/qnorm.pdf	}
	
	Bolstad, B. M., Irizarry R. A., Astrand, M., and Speed, T. P.
     	(2003), A comparison of normalization methods for high density
     	oligonucleotide array data based on bias and variance.
     	Bioinformatics 19, 185-193.

	Smyth, G. K. (2005). Limma: linear models for microarray data. In: 
	'Bioinformatics and Computational Biology Solutions Using R and 
	Bioconductor'. R. Gentleman, V. Carey, S. Dudoit, R. Irizarry, 
	W. Huber (eds), Springer, New York, pages 397 - 420
}
\author{Pedro Lopez-Romero}
\seealso{
	Agilent Feature Extraction Reference Guide
         \url{http://www.Agilent.com}
	See also 'backgroundCorrect' and 'normalizeBetweenArrays' in the limma package
     	and 'vsn' in the vsn package.
 }
\examples{
\dontrun{
	 data(dd) 
	 ddNORM=BGandNorm(dd,BGmethod='half',NORMmethod='quantile',
                        foreground='MeanSignal',background='BGMedianSignal',
                        offset=50,makePLOTpre=TRUE,makePLOTpost=TRUE)
}
}
\keyword{documentation}
\keyword{utilities}

