\name{build.mappings}
\alias{build.mappings}
\title{ Creates data.frame with  
	information mapped from the annotation package }
\description{
	Data frame with the mappings for the PROBE ID in the corresponding
	annotation package
}
\usage{
build.mappings(esetPROC, annotation.package)
}
\arguments{
  \item{esetPROC}{Expression Set object containing processed DATA  }
  \item{annotation.package}{character specifying the AGI annotation package: 'hgug4112a.db','mgug4122a.db'}
}
\details{
	Creates a data.frame: by rows it contains PROBE IDs and  
	by columns contains "ACCNUM","SYMBOL","ENTREZID", 
	"DESCRIPTION","GO.Id" and "GO.Terms" for each probe. Mappings
	are extracted from the corresponding annotation package. 	
	Usually this function is applied to an Expression Set object containing
	the processed data
}
\value{
	data.frame 
}
\author{ Pedro Lopez-Romero }
\seealso{  \code{\link{build.eset}} }
\examples{
\dontrun{
	data(dd)
	data(targets) 
	library(hgug4112a.db)
        selSNR=which(dd$genes$ControlType==0)
        dd.aux=dd[selSNR,]
        index=which(duplicated(dd.aux$genes$ProbeName)==FALSE)
        dd.aux=dd.aux[index,]
        eset.test=build.eset(dd.aux,targets,makePLOT=FALSE,
                annotation.package="hgug4112a.db")

	mappings=build.mappings(eset.test,"hgug4112a.db")
	names(mappings)
}
}
\keyword{documentation}
\keyword{utilities}

