\name{filter.wellaboveBG}
\alias{filter.wellaboveBG}
\title{  probes.filter (Internal function) }
\description{
	An internal function to be used by \code{\link{filter.probes}}
}
\usage{
filter.wellaboveBG(ddFILT, limWellAbove, ManuelaGO, targets, annotation.package)
}
\arguments{
  \item{ddFILT}{an RGlist object   }
  \item{limWellAbove}{for a given feature xi accros samples, is the
                minimum % of probes that is demanded to remain
                in an experimental condition with a wellaboveBG-FLAG = 1 (Is Well Above BG) }
  \item{ManuelaGO}{logical, if a known annotation package is available then
        it is \code{TRUE}  }
  \item{targets}{data.frame with the target structure  }
  \item{annotation.package}{ a character specifying the AGI annotation package: 'hgug4112a.db','mgug4122a.db'  }
}
\details{
	It eliminates signals that were not distinguishable from the local background signal. 
	The filtering is based on the FLAG given by the AFE as follows:
		For a feature = xi accross all the samples, 
		we demand that at least p% of the
                spots for that feature, in at least one experimental condition, had a
                quantification flag denoting that the signal is distinguishable from
                background. 
	AFE produces  a Boolean flag indicating if a spot is WellAbove
        Background (Flag = 1) or not (Flag = 0). A spot reaches a
        Flag = 1 if IsPosAndSignif and additionally the gBGSubSignal
        is greater than 2.6*g(r)BG\_SD.
        IsPosAndSignif uses a Boolean flag, established via a 2-sided t-test,
        indicates if the mean signal of a spot is greater than the
        corresponding background. 1 indicates spot is positive and
        significant above background. 
}
\value{
	An RGlist with probes that are above BG 
	(according to the correspondind AFE flag and the filtering options). 
	It also writes an output file (IsNOTWellAboveBG.txt) that 
	contains the probes that were filtered out because
        they were not distinguishable from the local background signal.
}
\author{ Pedro Lopez-Romero }
\seealso{  \code{\link{filter.probes}} }
\examples{
\dontrun{
	data(dd)
        data(targets)
	library(hgug4112a.db)
	ddFILT=filter.wellaboveBG(dd,75,TRUE,targets,"hgug4112a.db")	
        dim(ddFILT)
}
}
\keyword{documentation}
\keyword{utilities}

