\name{filter.wellaboveNEG}
\alias{filter.wellaboveNEG}
\title{  probes.filter (Internal function) }
\description{
	 An internal function to be used by \code{\link{filter.probes}}
}
\usage{
filter.wellaboveNEG(ddFILT, ddNORM, limNEG, SDtimes, ManuelaGO, targets, annotation.package)
}
\arguments{
  \item{ddFILT}{A RGlist in log2 scale, normally after Normalization and other filtering steps  }
  \item{ddNORM}{ An RGlist normally containing NORMALIZED data in log2 scale  }
  \item{limNEG}{  for a given feature xi accros samples, is the
                minimum % of spots that is demanded to remain
                in a experimental condition with a intensity > Limit established
                for negative controls (Mean + 1.5 x SD)}
  \item{SDtimes}{1.5 in 'Mean + 1.5 x SD'. It is fixed to 1.5 in 'filter.probes'  }
  \item{ManuelaGO}{ logical, if a known annotation package is available then
        it is \code{TRUE} }
  \item{targets}{data.frame with the target structure }
  \item{annotation.package}{  a character specifying the AGI annotation package: 'hgug4112a.db','mgug4122a.db' }
}
\details{
	For each feature we can demand a minimum signal value
        that have to be reached at least for a p% of the probes replicates 
        in one of the experimental conditions. The minimum limit is established as
        Mean Negative Controls  + 1.5*(Std. dev.Negative Controls).
        Normally, after filtering by the WellAboveBG and IsFound criteria,
        all probes are well above negative controls.
}
\value{
	An RGlist with signals that are above NEG controls 
        (according to the correspondind AFE flag and the filtering options).
        It also writes an output file (IsNOTWellAboveNEG.txt) that
        contains probes that were filtered out because
        they were not distinguishable from negative controls.

}
\author{ Pedro Lopez-Romero }
\seealso{ \code{\link{filter.probes}}}
\examples{
\dontrun{
        data(dd)
        data(targets)
	library(hgug4112a.db)
	ddNORM=BGandNorm(dd,BGmethod='half',NORMmethod='quantile',
                        foreground='MeanSignal',background='BGMedianSignal',
                        offset=50,makePLOTpre=FALSE,makePLOTpost=FALSE)
	ddFILT=filter.wellaboveBG(ddNORM,75,TRUE,targets,"hgug4112a.db")
	ddFILT2=filter.wellaboveNEG(ddFILT,ddNORM,75,SDtimes=1.5,TRUE,targets,"hgug4112a.db")
        dim(ddFILT2)
}
}
\keyword{documentation}
\keyword{utilities}

